@@ -1,4 +1,5 @@
 import requests as req
+import warnings
 
 import statsbombpy.entities as ents
 
@@ -31,3 +32,8 @@ def events(match_id: int) -> dict:
     events = req.get(OPEN_DATA_PATHS["events"].format(match_id=match_id)).json()
     events = ents.events(events, match_id)
     return events
+
+def frames(match_id: int) -> dict:
+    frames = req.get(OPEN_DATA_PATHS["frames"].format(match_id=match_id)).json()
+    frames = ents.frames(frames, match_id)
+    return frames
\ No newline at end of file
